@@ -67,7 +67,7 @@ def to_section_dict(gdf: gpd.geodataframe.GeoDataFrame, section_column: str = 's
         raise TypeError('resolution must be of type list')
 
     # Checking if X and Y values are in column
-    if np.logical_not(pd.Series(['X', 'Y']).isin(gdf.columns).all()):
+    if not {'X', 'Y'}.issubset(gdf.columns):
         gdf = vector.extract_xy(gdf)
 
     if len(resolution) != 2:
@@ -109,7 +109,7 @@ def convert_to_gempy_df(gdf: gpd.geodataframe.GeoDataFrame, **kwargs) -> pd.Data
         dem = kwargs.get('dem', None)
         extent = kwargs.get('extent', None)
         if not isinstance(dem, type(None)):
-            gdf = vector.extract_coordinates(gdf, dem, inplace=False, extent=extent)
+            gdf = vector.extract_xyz(gdf, dem, extent=extent)
         else:
             raise FileNotFoundError('DEM not provided')
     if np.logical_not(pd.Series(['formation']).isin(gdf.columns).all()):
@@ -575,7 +575,7 @@ def calculate_orientations(gdf: gpd.geodataframe.GeoDataFrame) -> pd.DataFrame:
         raise ValueError('IDs must not be None')
 
     # Extract XY coordinates
-    gdf_new = vector.extract_xy(gdf, inplace=False, drop_id=False, reset_index=False)
+    gdf_new = vector.extract_xy(gdf, drop_id=False, reset_index=False)
 
     # Create empty lists
     orientations = []
@@ -802,6 +802,10 @@ def calculate_lines(gdf: Union[gpd.geodataframe.GeoDataFrame, pd.DataFrame], inc
     if not isinstance(gdf, (gpd.geodataframe.GeoDataFrame, pd.DataFrame)):
         raise TypeError('gdf must be of type GeoDataFrame')
 
+    # Checking that all geometries are valid
+    if not all(gdf.geometry.is_valid):
+        raise ValueError('Not all Shapely Objects are valid objects')
+
     # Checking if the increment is of type float or int
     if not isinstance(increment, (float, int)):
         raise TypeError('The increment must be provided as float or int')
@@ -986,301 +990,6 @@ def show_number_of_data_points(geo_model):
     geo_model.add_surface_values([no_int, no_ori], ['No. of Interfaces', 'No. of Orientations'])
 
 
-# Function tested
-def calculate_strike(pd_series: pd.core.series.Series) -> Union[float, list]:
-    """
-    Calculating the strike of a profile line
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace
-    Return:
-        angle: float/list of strike angle/s of the profile
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Calculating strike angle
-    if pd_series.geometry.coords[0][0] < pd_series.geometry.coords[-1][0]:
-        angle = [180 - np.rad2deg(np.arccos(
-            (pd_series.geometry.coords[i][1] - pd_series.geometry.coords[i + 1][1]) / pd_series.geometry.length)) for
-                 i in range(len(pd_series.geometry.coords) - 1)]
-    else:
-        angle = [180 - np.rad2deg(np.arccos(
-            (pd_series.geometry.coords[i + 1][1] - pd_series.geometry.coords[i][1]) / pd_series.geometry.length)) for
-                 i in range(len(pd_series.geometry.coords) - 1)]
-
-    # Return list or float based on length of returning list
-    if len(angle) == 1:
-        return angle[0]
-    else:
-        return angle
-
-
-# Function tested
-def calculate_profile_angle(angle: float) -> float:
-    """
-    Calculate profile angle
-    Args:
-        angle: float of the strike angle of the profile
-    Return:
-        profile_angle: float of the angle of the profile
-    """
-
-    # Checking that the angle is of type float or int
-    if not isinstance(angle, (float, int)):
-        raise TypeError('Angle must be of type float or int')
-
-    # Calculating profile angle
-    if angle < 90:
-        profile_angle = 90 - angle
-    else:
-        profile_angle = 180 - angle
-
-    return profile_angle
-
-
-# Function tested
-def calculate_coordinates_point(pd_series: pd.core.series.Series, point: tuple, formation: str) -> tuple:
-    """
-    Calculate the coordinates for a point on a cross section
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace
-        point: tuple with the coordinates of the point of which the coordinates are calculated
-        formation: string containing the formation name associated with the coordinates
-    Return:
-        coordinates: tuple containing the x,y and z coordinate of the point
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that the point is tuple extracted from a linestring
-    if not isinstance(point, tuple):
-        raise TypeError('The coordinates of the provided point must be stored as tuple')
-
-    # Checking that the tuple only contains two coordinates
-    if len(point) != 2:
-        raise ValueError('The point must only contain a X and Z value')
-
-    # Calculate strike angle of profile
-    angle = calculate_strike(pd_series)
-
-    # Calculate profile angle
-    profile_angle = calculate_profile_angle(angle)
-
-    # Calculate coordinates
-    if angle >= 90:
-        # Calculate x and y components from digitized point to origin
-        x_ = np.sin(np.deg2rad(profile_angle)) * point[0]
-        y_ = np.cos(np.deg2rad(profile_angle)) * point[0]
-
-        if (pd_series.geometry.coords[0][0] < pd_series.geometry.coords[1][0]) & \
-                (pd_series.geometry.coords[0][1] > pd_series.geometry.coords[1][1]):
-
-            x = pd_series.geometry.coords[0][0] + x_
-            y = pd_series.geometry.coords[0][1] - y_
-        else:
-
-            x = pd_series.geometry.coords[1][0] + x_
-            y = pd_series.geometry.coords[1][1] - y_
-    else:
-        # Calculate x and y components from digitized point to origin
-        x_ = np.sin(np.deg2rad(profile_angle)) * point[0]
-        y_ = np.cos(np.deg2rad(profile_angle)) * point[0]
-
-        if (pd_series.geometry.coords[0][0] < pd_series.geometry.coords[1][0]) & \
-                (pd_series.geometry.coords[0][1] > pd_series.geometry.coords[1][1]):
-
-            x = pd_series.geometry.coords[0][0] + x_
-            y = pd_series.geometry.coords[0][1] + y_
-        else:
-
-            x = pd_series.geometry.coords[1][0] + x_
-            y = pd_series.geometry.coords[1][1] + y_
-
-    return x, y, point[1], formation
-
-
-# Function tested
-def calculate_coordinates_linestring(pd_series: pd.core.series.Series,
-                                     linestring: shapely.geometry.linestring.LineString, formation: str) -> List[tuple]:
-    """
-    Calculate coordinates of points in a linestring
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace
-        linestring: shapely linestring containing the interface points of a layer boundary
-        formation: string containing the formation name associated with the coordinates
-    Return:
-        coordinates: list of tuples containing the coordinates of the extracted point
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that the linestring is a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Calculating the coordinates of a linestring
-    coordinates = [calculate_coordinates_point(pd_series, i, formation) for i in linestring.coords]
-
-    return coordinates
-
-
-# Function tested
-def calculate_coordinates_from_cross_section(pd_series: pd.core.series.Series, gdf: gpd.geodataframe.GeoDataFrame) \
-        -> gpd.geodataframe.GeoDataFrame:
-    """
-    Calculate coordinates of all points in a linestring
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace of a geological map
-        gdf: GeoDataFrame containing multiple linestrings representing layer boundaries on a geological profile
-    Return:
-        gdf: GeoDataFrame of geom_type point containing the real world coordinates of interface points digitized on a
-        cross section
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that the gdf is a GeoDataFrame
-    if not isinstance(gdf, gpd.geodataframe.GeoDataFrame):
-        raise TypeError('The gdf must be a Geopandas GeoDataFrame')
-
-    # Checking that the gdf contains only linestrings
-    if not all(gdf.geom_type == 'LineString'):
-        raise TypeError('All elements of the GeoDataFrame must be of geometry type LineString')
-
-    # Calculate coordinates for all LineStrings
-    coordinates = [calculate_coordinates_linestring(pd_series, gdf.iloc[i].geometry, gdf.iloc[i]['formation']) for i in
-                   range(len(gdf))]
-
-    # Collect all DataFrames in a list
-    dfs = [pd.DataFrame(coordinates[i], columns=['X', 'Y', 'Z', 'formation']) for i in range(len(coordinates))]
-
-    # Concat DataFrames to a single Data
-    df = pd.concat(dfs)
-
-    # Create GeoDataFrame from DataFrames
-    gdf = gpd.GeoDataFrame(df, geometry=gpd.points_from_xy(df.X, df.Y), crs=gdf.crs)
-
-    return gdf
-
-
-# Function tested
-def calculate_orientations_from_cross_section(pd_series: pd.core.series.Series, gdf: gpd.geodataframe.GeoDataFrame) \
-        -> gpd.geodataframe.GeoDataFrame:
-    """
-    Calculate orientations of a linestring digitized on a cross section
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace of a geological map
-        gdf: GeoDataFrame containing multiple linestrings representing orientations on a geological profile
-    Return:
-        gdf: GeoDataFrame of geom_type point containing the real world coordinates and orientation values of
-        lines digitized on a cross section
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that the gdf is a GeoDataFrame
-    if not isinstance(gdf, gpd.geodataframe.GeoDataFrame):
-        raise TypeError('The gdf must be a Geopandas GeoDataFrame')
-
-    # Checking that the gdf contains only linestrings
-    if not all(gdf.geom_type == 'LineString'):
-        raise TypeError('All elements of the GeoDataFrame must be of geometry type LineString')
-
-    # Calculate coordinates for all LineStrings
-    coordinates = [calculate_orientations_linestring(pd_series, gdf.iloc[i].geometry, gdf.iloc[i]['formation']) for i
-                   in range(len(gdf))]
-
-    # Create DataFrame from List
-    df = pd.DataFrame(coordinates, columns=['X', 'Y', 'Z', 'formation', 'dip', 'azimuth', 'polarity'])
-
-    # Create GeoDataFrame from DataFrame
-    gdf = gpd.GeoDataFrame(df, geometry=gpd.points_from_xy(df.X, df.Y), crs=gdf.crs)
-
-    return gdf
-
-
-# Function tested
-def calculate_orientations_linestring(pd_series: pd.core.series.Series,
-                                      linestring: shapely.geometry.linestring.LineString, formation: str) -> tuple:
-    """
-    Calculate orientations of a linestring digitized on a cross section
-    Args:
-        pd_series: Pandas series containing the linestring of a profile trace
-        linestring: shapely linestring containing the interface points of a layer boundary
-        formation: string containing the formation name associated with the coordinates
-    Return:
-        coordinates: list of tuples containing the coordinates and orientations of the digitized line
-    """
-
-    # Checking that pd_series is a pandas series
-    if not isinstance(pd_series, pd.core.series.Series):
-        raise TypeError('Profile line must be a Pandas Series')
-
-    # Checking that the pd_series contains a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that the linestring is a linestring
-    if not isinstance(pd_series.geometry, shapely.geometry.linestring.LineString):
-        raise TypeError('Geometry object of pandas series must be a shapely linestring')
-
-    # Checking that only two coordinates are in a linestring
-    if len(linestring.coords) != 2:
-        raise ValueError('Two vertices per LineString are required to calculate an orientation')
-
-    # Calculate dip of linestring
-    dip = np.abs(np.rad2deg(np.arctan((linestring.coords[1][1] - linestring.coords[0][1]) /
-                                      (linestring.coords[1][0] - linestring.coords[0][0]))))
-
-    # Calculate azimuth of LineString
-    if (linestring.coords[0][0] < linestring.coords[1][0]) & (linestring.coords[0][1] > linestring.coords[1][1]):
-        azimuth = calculate_strike(pd_series)
-    else:
-        azimuth = 180 - calculate_strike(pd_series)
-
-    # Setting polarity to 1
-    polarity = 1
-
-    # Calculating the midpoint to calculate coordinates of orientation
-    midpoint_x = (linestring.coords[1][0] + linestring.coords[0][0]) / 2
-    midpoint_y = (linestring.coords[1][1] + linestring.coords[0][1]) / 2
-
-    # Calculating the coordinates and orientations from a linestring
-    coordinates = calculate_coordinates_point(pd_series, (midpoint_x, midpoint_y), formation)
-
-    return coordinates[0], coordinates[1], coordinates[2], coordinates[3], dip, azimuth, polarity
-
-
 # Function tested
 def get_location_coordinate(name: str) -> geopy.location.Location:
     """
